summaryrefslogtreecommitdiffstats
path: root/konqueror/sidebar/trees/konq_sidebartree.h
diff options
context:
space:
mode:
Diffstat (limited to 'konqueror/sidebar/trees/konq_sidebartree.h')
-rw-r--r--konqueror/sidebar/trees/konq_sidebartree.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/konqueror/sidebar/trees/konq_sidebartree.h b/konqueror/sidebar/trees/konq_sidebartree.h
index a8e2ad075..f8626298c 100644
--- a/konqueror/sidebar/trees/konq_sidebartree.h
+++ b/konqueror/sidebar/trees/konq_sidebartree.h
@@ -31,7 +31,7 @@
class KonqSidebarTreeModule;
class KonqSidebarTreeItem;
-class KActionCollection;
+class TDEActionCollection;
class TQTimer;
@@ -64,7 +64,7 @@ private:
typedef enum {
SidebarTreeMode, // used if the drop is accepted by a KonqSidebarTreeItem. otherwise
- KListViewMode // use KListView's dnd implementation. accepts mime types set with setDropFormats()
+ TDEListViewMode // use TDEListView's dnd implementation. accepts mime types set with setDropFormats()
} DropAcceptType;
/**
@@ -73,7 +73,7 @@ typedef enum {
* a toplevel item, and creates the modules that will handle the contents
* of those items.
*/
-class KonqSidebarTree : public KListView, public KDirNotify
+class KonqSidebarTree : public TDEListView, public KDirNotify
{
Q_OBJECT
public:
@@ -106,7 +106,7 @@ public:
void itemDestructed( KonqSidebarTreeItem *item );
- void setDropFormats( const TQStringList &formats ); // used in KListView mode
+ void setDropFormats( const TQStringList &formats ); // used in TDEListView mode
// Show context menu for toplevel items
void showToplevelContextMenu();
@@ -125,7 +125,7 @@ protected:
virtual void contentsDragMoveEvent( TQDragMoveEvent *e );
virtual void contentsDragLeaveEvent( TQDragLeaveEvent *e );
virtual void contentsDropEvent( TQDropEvent *ev );
- virtual bool acceptDrag(TQDropEvent* e) const; // used in KListView mode
+ virtual bool acceptDrag(TQDropEvent* e) const; // used in TDEListView mode
virtual void leaveEvent( TQEvent * );
@@ -205,7 +205,7 @@ private:
TQMap<TQString, getModule> pluginFactories;
bool m_bOpeningFirstChild;
- KActionCollection *m_collection;
+ TDEActionCollection *m_collection;
KonqSidebarTree_Internal *d;